@@ -11,10 +11,8 @@ sed -i -e "s#\$PWD#$PWD#g" cron/{{ jobName }}
 chmod +x cron/{{ jobName }}
 
 if (( $(crontab -l | grep -c "cron_{{ jobName }}" ) == 0 )) ; then
-    crontab -l > _cron
-    if (( $(crontab -l | grep -c "APP_NAME=" ) == 0 )) ; then
-        env >> _cron
-    fi
+    crontab -l > _cron  
+    env >> _cron  
     echo "{{ time }} $PWD/cron/{{ jobName }} >> $HOME/app/log/cron_{{ jobName }}.log" >> _cron
 fi
 crontab _cron
