@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11369 2019-02-19 13:16:39Z Lavender $
+# $Id: __init__.py 11380 2019-03-08 13:06:02Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-02-19 22:16:39 +0900 (週二, 19 二月 2019) $
-# $Revision: 11369 $
+# $Date: 2019-03-08 22:06:02 +0900 (週五, 08 三月 2019) $
+# $Revision: 11380 $
 
 import os
 import sys
@@ -188,9 +188,14 @@ def attachSettings(settingsDict, enablePaypal=False):
     extendTemplateContextProcessors(settingsDict, 
                                     ADDING_TEMPLATES_CONTEXT_PROCESSORS)
 
+    overrideTemplateDir = os.path.join(
+        os.path.dirname(os.path.abspath(__file__)), 
+        os.path.join("templates", "shop", "override"))
+        
     # Template tags
     ADDING_TEMPLATES_DIRS = [
         os.path.join(settingsDict['BASE_DIR'], 'templates'),
+        overrideTemplateDir,
         OSCAR_MAIN_TEMPLATE_DIR,
     ]
     extendTemplateDirs(settingsDict, ADDING_TEMPLATES_DIRS)
@@ -457,6 +462,15 @@ def attachShopURLs(settings, urlpatterns):
         (r'^i18n/', include('django.conf.urls.i18n')),
         (r'^shop/', shop.urls),
     )
+    
+    ckeditorEnable = False
+    if hasattr(settings, 'IUNO_SHOP_PRODUCT_DESCRIPTION_CKEDITOR'):
+        ckeditorEnable = settings.IUNO_SHOP_PRODUCT_DESCRIPTION_CKEDITOR
+    
+    if ckeditorEnable:
+        urlpatterns += patterns('',
+            url(r'^ckeditor/', include('ckeditor_uploader.urls')),
+        )
 
     paypalEnable = False
     if hasattr(settings, 'IUNO_SHOP_PAYPAL_ENABLE'):
